ExExample.Behaviour behaviour (ExExample v0.1.1)
View SourceI help determine when Examples ought to be run again or be copied
I do this by defining out a behaviour that is to be used with the use macro for ExExample
I help determine when Examples ought to be run again or be copied
I do this by defining out a behaviour that is to be used with the use macro for ExExample